diff --git a/v2rayN/ServiceLib/Resx/ResUI.resx b/v2rayN/ServiceLib/Resx/ResUI.resx
index eed7d28b..2f27bf35 100644
--- a/v2rayN/ServiceLib/Resx/ResUI.resx
+++ b/v2rayN/ServiceLib/Resx/ResUI.resx
@@ -1321,4 +1321,7 @@
Host filter
+
+ Active
+
\ No newline at end of file
diff --git a/v2rayN/ServiceLib/Resx/ResUI.zh-Hans.resx b/v2rayN/ServiceLib/Resx/ResUI.zh-Hans.resx
index cb144224..8e632e25 100644
--- a/v2rayN/ServiceLib/Resx/ResUI.zh-Hans.resx
+++ b/v2rayN/ServiceLib/Resx/ResUI.zh-Hans.resx
@@ -1318,4 +1318,7 @@
主机过滤器
+
+ 活动
+
\ No newline at end of file
diff --git a/v2rayN/ServiceLib/Resx/ResUI.zh-Hant.resx b/v2rayN/ServiceLib/Resx/ResUI.zh-Hant.resx
index be5f5c02..516a61f1 100644
--- a/v2rayN/ServiceLib/Resx/ResUI.zh-Hant.resx
+++ b/v2rayN/ServiceLib/Resx/ResUI.zh-Hant.resx
@@ -1198,4 +1198,7 @@
主機過濾
+
+ 活動
+
\ No newline at end of file
diff --git a/v2rayN/v2rayN.Desktop/Views/ProfilesView.axaml b/v2rayN/v2rayN.Desktop/Views/ProfilesView.axaml
index 1208e959..93599aa8 100644
--- a/v2rayN/v2rayN.Desktop/Views/ProfilesView.axaml
+++ b/v2rayN/v2rayN.Desktop/Views/ProfilesView.axaml
@@ -83,7 +83,7 @@
BorderThickness="1"
CanUserResizeColumns="True"
GridLinesVisibility="All"
- HeadersVisibility="Column"
+ HeadersVisibility="All"
IsReadOnly="True"
ItemsSource="{Binding ProfileItems}">
@@ -143,20 +143,34 @@
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/v2rayN/ServiceLib/Resx/ResUI.Designer.cs b/v2rayN/ServiceLib/Resx/ResUI.Designer.cs
index 8f11ce22..a93c5491 100644
--- a/v2rayN/ServiceLib/Resx/ResUI.Designer.cs
+++ b/v2rayN/ServiceLib/Resx/ResUI.Designer.cs
@@ -673,7 +673,7 @@ namespace ServiceLib.Resx {
}
///
- /// 查找类似 Importing Share Links from clipboard (Ctrl+V) 的本地化字符串。
+ /// 查找类似 Import Share Links from clipboard (Ctrl+V) 的本地化字符串。
///
public static string menuAddServerViaClipboard {
get {
@@ -1717,7 +1717,7 @@ namespace ServiceLib.Resx {
}
///
/// 查找类似 Servers Filter, press Enter to execute 的本地化字符串。
///
public static string MsgServerTitle {
get {
@@ -3481,6 +3481,15 @@ namespace ServiceLib.Resx {
}
}
+ ///
+ /// 查找类似 Active 的本地化字符串。
+ ///
+ public static string TipActiveServer {
+ get {
+ return ResourceManager.GetString("TipActiveServer", resourceCulture);
+ }
+ }
+
///
/// 查找类似 Routing setting is changed 的本地化字符串。
///
@@ -1717,7 +1717,7 @@ namespace ServiceLib.Resx {
}
///
- /// 查找类似 Servers Filter, press Enter to execute 的本地化字符串。
+ /// 查找类似 Server filter, press Enter to execute 的本地化字符串。
///
public static string MsgServerTitle {